@@ -11,14 +11,18 @@ import logging
 import shutil
 from io import StringIO
 from edk2toolext.environment.external_dependency import ExternalDependency
-from edk2toollib.utility_functions import RunCmd
+from edk2toollib.utility_functions import RunCmd, RemoveTree
 from edk2toollib.utility_functions import GetHostInfo
 import pkg_resources
+from typing import List
 
 
 class NugetDependency(ExternalDependency):
     TypeString = "nuget"
 
+    ''' Env variable name for path to folder containing NuGet.exe'''
+    NUGET_ENV_VAR_NAME = "NUGET_PATH"
+
     def __init__(self, descriptor):
         super().__init__(descriptor)
         self.global_cache_path = None
@@ -28,32 +32,38 @@ class NugetDependency(ExternalDependency):
     # Used to add nuget support on posix platforms.
     # https://docs.microsoft.com/en-us/nuget/install-nuget-client-tools
     #
+    # Note that the strings returned might not be pathlike given they may be
+    # quoted for use on command line
+    #
     # @return list containing either ["nuget.exe"] or ["mono", "/PATH/TO/nuget.exe"]
+    # @return none if not found
     ####
-    @staticmethod
-    def GetNugetCmd():
-        file = "NuGet.exe"
+    @classmethod
+    def GetNugetCmd(cls) -> List[str]:
+        file_name = "NuGet.exe"
         cmd = []
         if GetHostInfo().os == "Linux":
             cmd += ["mono"]
-        # TODO Find the Nuget rom our bin file
-        requirement = pkg_resources.Requirement.parse("edk2-pytool-extensions")
-        nuget_file_path = os.path.join("edk2toolext", "bin", file)
-        nuget_path = pkg_resources.resource_filename(requirement, nuget_file_path)
 
-        # check if we don't have it, look for nuget in the path
-        if not os.path.isfile(nuget_path):
-            for env_var in os.getenv("PATH").split(os.pathsep):
-                env_var = os.path.join(os.path.normpath(env_var), file)
-                if os.path.isfile(env_var):
-                    nuget_path = '"' + env_var + '"'
-                    break
-        # we've probably found something by now?
-        cmd += [nuget_path]
-        # if we're still hosed
+        nuget_path = os.getenv(cls.NUGET_ENV_VAR_NAME)
+        if nuget_path is None:
+            # No env variable found.  Get it from our package
+            requirement = pkg_resources.Requirement.parse("edk2-pytool-extensions")
+            nuget_file_path = os.path.join("edk2toolext", "bin")
+            nuget_path = pkg_resources.resource_filename(requirement, nuget_file_path)
+
+        nuget_path = os.path.join(nuget_path, file_name)
+
         if not os.path.isfile(nuget_path):
             logging.error("We weren't able to find Nuget! Please reinstall your pip environment")
             return None
+
+        # Make sure quoted string if it has spaces
+        if " " in nuget_path.strip():
+            nuget_path = '"' + nuget_path + '"'
+
+        cmd += [nuget_path]
+
         return cmd
 
     @staticmethod
@@ -227,15 +237,7 @@ class NugetDependency(ExternalDependency):
             source_dir = os.path.join(temp_directory, package_name)
         shutil.copytree(source_dir, self.contents_dir)
 
-        for _ in range(3):  # rmtree doesn't always remove all files. Attempt delete up to 3 times.
-            try:
-                shutil.rmtree(source_dir)
-            except OSError as err:
-                logging.warning(f"Failed to fully remove {source_dir}: {err}")
-            else:
-                break
-        else:
-            raise RuntimeError(f"Failed to remove {source_dir}")
+        RemoveTree(source_dir)
 
         #
         # Add a file to track the state of the dependency.
@@ -245,7 +247,7 @@ class NugetDependency(ExternalDependency):
         #
         # Finally, delete the temp directory.
         #
-        self._clean_directory(temp_directory)
+        RemoveTree(temp_directory)
 
         # The published path may change now that the package has been unpacked.
         self.published_path = self.compute_published_path()
@@ -256,4 +258,4 @@ class NugetDependency(ExternalDependency):
     def clean(self):
         super(NugetDependency, self).clean()
         if os.path.isdir(self.get_temp_dir()):
-            self._clean_directory(self.get_temp_dir())
+            RemoveTree(self.get_temp_dir())
