@@ -14,13 +14,12 @@ import logging
 from edk2toolext.environment.multiple_workspace import MultipleWorkspace
 from edk2toolext.environment import conf_mgmt
 import traceback
-import shutil
 import time
 from edk2toolext.environment import shell_environment
 from edk2toollib.uefi.edk2.parsers.targettxt_parser import TargetTxtParser
 from edk2toollib.uefi.edk2.parsers.dsc_parser import DscParser
 from edk2toollib.uefi.edk2.parsers.fdf_parser import FdfParser
-from edk2toollib.utility_functions import RunCmd
+from edk2toollib.utility_functions import RunCmd, RemoveTree
 from edk2toolext import edk2_logging
 from edk2toolext.environment.plugintypes.uefi_build_plugin import IUefiBuildPlugin
 import datetime
@@ -68,23 +67,18 @@ class UefiBuilder(object):
         '''  Retrieve command line options from the argparser'''
         self.OutputConfig = os.path.abspath(args.OutputConfig) if args.OutputConfig else None
 
-        if(args.SKIPBUILD):
-            self.SkipBuild = True
-        elif(args.SKIPPREBUILD):
-            self.SkipPreBuild = True
-        elif(args.SKIPPOSTBUILD):
-            self.SkipPostBuild = True
-        elif(args.FLASHONLY):
+        self.SkipBuild = args.SKIPBUILD
+        self.SkipPreBuild = args.SKIPPREBUILD
+        self.SkipPostBuild = args.SKIPPOSTBUILD
+        self.Clean = args.CLEAN
+        self.FlashImage = args.FLASHROM
+        self.UpdateConf = args.UPDATECONF
+
+        if(args.FLASHONLY):
             self.SkipPostBuild = True
             self.SkipBuild = True
             self.SkipPreBuild = True
             self.FlashImage = True
-        elif(args.FLASHROM):
-            self.FlashImage = True
-        elif(args.UPDATECONF):
-            self.UpdateConf = True
-        elif(args.CLEAN):
-            self.Clean = True
         elif(args.CLEANONLY):
             self.Clean = True
             self.SkipBuild = True
@@ -204,7 +198,7 @@ class UefiBuilder(object):
             logging.debug("Removing [%s]", d)
             # if the folder is opened in Explorer do not fail the entire Rebuild
             try:
-                shutil.rmtree(d)
+                RemoveTree(d)
             except WindowsError as wex:
                 logging.debug(wex)
 
@@ -215,15 +209,15 @@ class UefiBuilder(object):
         # this needs to be removed in case build flags changed
         d = os.path.join(self.ws, "Conf", ".cache")
         if(os.path.isdir(d)):
-            shutil.rmtree(d)
             logging.debug("Removing [%s]" % d)
+            RemoveTree(d)
 
         if(RemoveConfTemplateFilesToo):
             for a in ["target.txt", "build_rule.txt", "tools_def.txt"]:
                 d = os.path.join(self.ws, "Conf", a)
                 if(os.path.isfile(d)):
-                    os.remove(d)
                     logging.debug("Removing [%s]" % d)
+                    os.remove(d)
 
         return ret
 
