@@ -16,7 +16,7 @@ from io import StringIO
 from edk2toolext import edk2_logging
 from edk2toollib.utility_functions import RunCmd
 
-# Omnicache version 0.11 design notes:
+# Omnicache version 0.11+ design notes:
 # 1. Only a single remote per URL will be permitted.
 # 2. Remote names inside omnicache will be UUIDs generated when a new URL is added.
 # 3. Users may specify names for remotes, but they will be treated simply as "display names" without git significance.
@@ -27,7 +27,7 @@ from edk2toollib.utility_functions import RunCmd
 #     older omnicache interacts with it. Older omnicache should not crash when encountering a newer omnicache directory
 #     but may take a lot of slow and unecessary actions to "re-initialize" it.
 
-OMNICACHE_VERSION = "0.11"
+OMNICACHE_VERSION = "0.12"
 
 # Prior to version 0.11, an "omnicache.yaml" file in the root of the omnicache repo was used to manage the cache
 # configuration. Starting with 0.11, git config entries are used directly. If the file below is present, it will be
@@ -74,6 +74,9 @@ class Omnicache():
             logging.debug("{0} error getting repo state - not valid (not convertible).".format(self.path))
             return (False, False)
         if (out.getvalue().strip().lower() == "true"):
+            if (os.path.exists(os.path.join(self.path, PRE_0_11_OMNICACHE_FILENAME))):
+                logging.debug("{0} - old config file present. not valid (is convertible).".format(self.path))
+                return (False, True)
             out = StringIO()
             ret = RunCmd("git", "config --local omnicache.metadata.version", workingdir=self.path, outstream=out)
             if (ret != 0):
@@ -95,6 +98,12 @@ class Omnicache():
         ret = RunCmd("git", "init --bare", workingdir=self.path)
         if (ret != 0):
             return ret
+        # by default, git fetch is single-threaded. This configuration allows git to use a "reasonable" default
+        # (presently equal to the number of cpus) to execute the fetch in parallel.
+        ret = RunCmd("git", "config --local fetch.parallel 0", workingdir=self.path)
+        if (ret != 0):
+            return ret
+
         return RunCmd("git",
                       "config --local omnicache.metadata.version {0}".format(OMNICACHE_VERSION),
                       workingdir=self.path)
@@ -113,7 +122,12 @@ class Omnicache():
                 newName = str(uuid.uuid4())
                 ret = RunCmd("git", "remote rename {0} {1}".format(name, newName), workingdir=self.path)
                 if (ret != 0):
-                    return ret
+                    # rename failed; try removal.
+                    logging.warn("Failed to rename {0}. Attempting to remove it.".format(name))
+                    ret = RunCmd("git", "remote remove {0}".format(name), workingdir=self.path)
+                    if (ret != 0):
+                        logging.critical("Failed to rename or remove {0} - skipping.".format(name))
+                        continue
                 # Remove previous fetch config entries and regenerate them. Proceed to create new ones even if it fails.
                 RunCmd("git", "config --local --unset-all remote.{0}.fetch".format(newName), workingdir=self.path)
                 RunCmd("git",
@@ -145,6 +159,11 @@ class Omnicache():
                 logging.info("Removing remote {0} with duplicate URL {1}".format(name, url))
                 RunCmd("git", "remote remove {0}".format(name), workingdir=self.path)
                 RunCmd("git", "config --local --unset omnicache.{0}.displayname".format(name), workingdir=self.path)
+        # by default, git fetch is single-threaded. This configuration allows git to use a "reasonable" default
+        # (presently equal to the number of cpus) to execute the fetch in parallel.
+        ret = RunCmd("git", "config --local fetch.parallel 0", workingdir=self.path)
+        if (ret != 0):
+            return ret
         # write current omnicache version into cache
         logging.info("Writing Omnicache version")
         return RunCmd("git",
@@ -239,13 +258,16 @@ class Omnicache():
 
         return 0
 
-    def Fetch(self):
+    def Fetch(self, jobs=0):
         """Fetches all remotes"""
         logging.info("Fetching all remotes.")
         self._RefreshUrlLookupCache()
         # Tricky: we pass no-tags here, since we set up custom fetch refs for tags on a per-remote basis. This prevents
         # git from fetching the first set of tags into the global namespace.
-        return RunCmd("git", "fetch --all -j {0} --no-tags".format(len(self.urlLookupCache)), workingdir=self.path)
+        if (jobs != 0):
+            return RunCmd("git", "fetch --all -j {0} --no-tags".format(jobs), workingdir=self.path)
+        else:
+            return RunCmd("git", "fetch --all --no-tags", workingdir=self.path)
 
     def GetRemoteData(self):
         """Gets Remote Data
@@ -393,6 +415,8 @@ def get_cli_options():
                        help="Update the Omnicache.  All cache changes also cause a fetch", default=False)
     group.add_argument("--no-fetch", dest="no_fetch", action="store_true",
                        help="Prevent auto-fetch if implied by other arguments.", default=False)
+    group.add_argument("--fetch-jobs", dest="fetch_jobs", type=int,
+                       help="Specify the number of parallel threads (jobs) for fetch operation.", default=0)
     parser.add_argument("-r", "--remove", dest="remove", nargs=1, action="append",
                         help="remove config entry from OMNICACHE <name>", default=[])
     parser.add_argument('--version', action='version', version='%(prog)s ' + OMNICACHE_VERSION)
@@ -480,7 +504,7 @@ def main():
     # Note: errors are ignored here, since transient network failures may occur that prevent cache update. Those just
     # mean the omnicache may be a a little stale which should not be fatal to users of the cache.
     if(args.fetch or (auto_fetch and not args.no_fetch)):
-        omnicache.Fetch()
+        omnicache.Fetch(args.fetch_jobs)
 
     # list: print out the omnicache contents.
     if (args.list):
