@@ -43,6 +43,15 @@ class Testself_describing_environment(unittest.TestCase):
         build_env, shell_env = self_describing_environment.BootstrapEnvironment(self.workspace, scopes)
         self.assertEqual(len(build_env.paths), 4)
 
+    def test_collect_path_env_scoped(self):
+        ''' makes sure the SDE can collect path env with the right scopes '''
+        scopes = ("global", "testing")
+        tree = uefi_tree(self.workspace, create_platform=False)
+        tree.create_path_env("testing_corebuild", scope="testing")
+        tree.create_path_env("testing_corebuild2", scope="not_valid")
+        build_env, shell_env = self_describing_environment.BootstrapEnvironment(self.workspace, scopes)
+        self.assertEqual(len(build_env.paths), 1)
+
     def test_override_path_env(self):
         ''' checks the SDE descriptor override system '''
         custom_scope = "global"
@@ -52,8 +61,32 @@ class Testself_describing_environment(unittest.TestCase):
         tree.create_path_env("testing_corebuild2", var_name="jokes", scope=custom_scope,
                              extra_data={"override_id": "testing_corebuild"})
         build_env, shell_env = self_describing_environment.BootstrapEnvironment(self.workspace, scopes)
-        print(build_env.paths)
-        print(tree.get_workspace())
+        self.assertEqual(len(build_env.paths), 1)
+
+    def test_multiple_override_path_env(self):
+        ''' checks the SDE descriptor override system will throw an error on multiple overrides'''
+        custom_scope = "global"
+        scopes = (custom_scope,)
+        tree = uefi_tree(self.workspace, create_platform=False)
+        tree.create_path_env("testing_corebuild", var_name="hey", dir_path="test1", scope=custom_scope)
+        tree.create_path_env("testing_corebuild2", var_name="jokes", scope=custom_scope,
+                             extra_data={"override_id": "testing_corebuild"})
+        tree.create_path_env("testing_corebuild3", var_name="laughs", scope=custom_scope,
+                             extra_data={"override_id": "testing_corebuild"})
+        # we should get an exception because we have two overrides
+        with self.assertRaises(RuntimeError):
+            build_env, shell_env = self_describing_environment.BootstrapEnvironment(self.workspace, scopes)
+            self.fail()
+
+    def test_override_path_env_swapped_order(self):
+        ''' checks the SDE descriptor override system with reversed paths so they are discovered in opposite order'''
+        custom_scope = "global"
+        scopes = (custom_scope,)
+        tree = uefi_tree(self.workspace, create_platform=False)
+        tree.create_path_env("testing_corebuild", var_name="hey", scope=custom_scope)
+        tree.create_path_env(var_name="jokes", dir_path="test1", scope=custom_scope,
+                             extra_data={"override_id": "testing_corebuild"})
+        build_env, shell_env = self_describing_environment.BootstrapEnvironment(self.workspace, scopes)
         self.assertEqual(len(build_env.paths), 1)
 
     def test_duplicate_id_path_env(self):
@@ -65,6 +98,7 @@ class Testself_describing_environment(unittest.TestCase):
         tree.create_path_env("testing_corebuild")
         with self.assertRaises(RuntimeError):
             self_describing_environment.BootstrapEnvironment(self.workspace, scopes)
+            self.fail()
 
 
 if __name__ == '__main__':
